@@ -1,5 +1,6 @@
 use v5.14;
 use warnings;
+use utf8;
 
 =head1 NAME
 
@@ -7,7 +8,7 @@ Attean::API::Plan - Query plan
 
 =head1 VERSION
 
-This document describes Attean::API::Plan version 0.012
+This document describes Attean::API::Plan version 0.019
 
 =head1 DESCRIPTION
 
@@ -52,11 +53,11 @@ L<Attean::API::Iterator> object.
 
 use Type::Tiny::Role;
 
-package Attean::API::Plan 0.012 {
-	use Moo::Role;
+package Attean::API::Plan 0.019 {
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ArrayRef CodeRef Str Object InstanceOf Bool Num Int);
-	use namespace::clean;
+
+	use Moo::Role;
 	
 	has 'cost' => (is => 'rw', isa => Int, predicate => 'has_cost');
 	has 'distinct' => (is => 'rw', isa => Bool, required => 1, default => 0);
@@ -65,17 +66,7 @@ package Attean::API::Plan 0.012 {
 	has 'ordered' => (is => 'ro', isa => ArrayRef, required => 1, default => sub { [] });
 	
 	requires 'impl';
-	
-=item C<< plan_as_string >>
-
-Returns a string representation of this plan, excluding children.
-
-=cut
-
-	sub plan_as_string {
-		my $self	= shift;
-		return "$self";
-	}
+	requires 'plan_as_string';
 
 =item C<< as_string >>
 
@@ -102,6 +93,9 @@ Returns a tree-structured string representation of this plan, including children
 				}
 				push(@flags, "order: " . join('; ', @orders));
 			}
+			if (defined(my $cost = $a->cost)) {
+				push(@flags, "cost: $cost");
+			}
 			$string	.= "-$indent " .  $a->plan_as_string($level);
 			if (scalar(@flags)) {
 				$string .= ' (' . join(' ', @flags) . ")";
@@ -213,7 +207,7 @@ product if this plan performs some form of join.
 	}
 }
 
-package Attean::API::BindingSubstitutionPlan 0.012 {
+package Attean::API::BindingSubstitutionPlan 0.019 {
 	use Moo::Role;
 	with 'Attean::API::Plan';
 	requires 'substitute_impl'; # $code = $plan->impl($model, $binding);
@@ -226,9 +220,8 @@ package Attean::API::BindingSubstitutionPlan 0.012 {
 	}
 }
 
-package Attean::API::UnionScopeVariablesPlan 0.012 {
+package Attean::API::UnionScopeVariablesPlan 0.019 {
 	use Moo::Role;
-	use namespace::clean;
 
 	with 'Attean::API::Plan';
 	
@@ -247,11 +240,11 @@ package Attean::API::UnionScopeVariablesPlan 0.012 {
 	};
 }
 
-package Attean::API::Plan::Join 0.012 {
-	use Moo::Role;
+package Attean::API::Plan::Join 0.019 {
 	use Types::Standard qw(CodeRef);
 	use Types::Standard qw(ArrayRef Str ConsumerOf Bool);
-	use namespace::clean;
+
+	use Moo::Role;
 
 	with 'Attean::API::Plan', 'Attean::API::BinaryQueryTree';
 	with 'Attean::API::UnionScopeVariablesPlan';
@@ -277,7 +270,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
@@ -285,7 +278,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams.
+Copyright (c) 2014--2018 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
