@@ -7,7 +7,7 @@ Attean::API::Serializer - Serializer role
 
 =head1 VERSION
 
-This document describes Attean::API::Serializer version 0.017
+This document describes Attean::API::Serializer version 0.019
 
 =head1 DESCRIPTION
 
@@ -68,7 +68,7 @@ UTF-8 encoded byte string.
 
 use Type::Tiny;
 
-package Attean::API::Serializer 0.017 {
+package Attean::API::Serializer 0.019 {
 	use Moo::Role;
 	use Carp qw(confess);
 	
@@ -105,11 +105,11 @@ package Attean::API::Serializer 0.017 {
 	}
 }
 
-package Attean::API::AbbreviatingSerializer 0.017 {
+package Attean::API::AbbreviatingSerializer 0.019 {
 	# Serializer that can make use of a base IRI and/or prefix IRI mappings
-	use Moo::Role;
 	use Types::Standard qw(InstanceOf ConsumerOf Maybe);
-	use namespace::clean;
+
+	use Moo::Role;
 
 	with 'Attean::API::Serializer';
 
@@ -117,13 +117,13 @@ package Attean::API::AbbreviatingSerializer 0.017 {
 	has namespaces	=> (is => 'ro', isa => Maybe[InstanceOf['URI::NamespaceMap']], predicate => 'has_namespaces');
 }
 
-package Attean::API::AppendableSerializer 0.017 {
+package Attean::API::AppendableSerializer 0.019 {
 	# Serializer for a format that allows multiple serialization calls to be appended and remain syntactically valid
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 }
 
-package Attean::API::TermSerializer 0.017 {
+package Attean::API::TermSerializer 0.019 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
@@ -132,7 +132,7 @@ package Attean::API::TermSerializer 0.017 {
 	}
 }
 
-package Attean::API::TripleSerializer 0.017 {
+package Attean::API::TripleSerializer 0.019 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
@@ -141,7 +141,7 @@ package Attean::API::TripleSerializer 0.017 {
 	}
 }
 
-package Attean::API::QuadSerializer 0.017 {
+package Attean::API::QuadSerializer 0.019 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	
@@ -151,7 +151,7 @@ package Attean::API::QuadSerializer 0.017 {
 	}
 }
 
-package Attean::API::MixedStatementSerializer 0.017 {
+package Attean::API::MixedStatementSerializer 0.019 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	
@@ -161,7 +161,7 @@ package Attean::API::MixedStatementSerializer 0.017 {
 	}
 }
 
-package Attean::API::ResultSerializer 0.017 {
+package Attean::API::ResultSerializer 0.019 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
@@ -204,7 +204,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
@@ -212,7 +212,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams.
+Copyright (c) 2014--2018 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
