@@ -7,7 +7,7 @@ Attean::API::Term - RDF Terms
 
 =head1 VERSION
 
-This document describes Attean::API::Term version 0.012
+This document describes Attean::API::Term version 0.019
 
 =head1 DESCRIPTION
 
@@ -41,7 +41,7 @@ Returns a string serialization of the term.
 
 =cut
 
-package Attean::API::Term 0.012 {
+package Attean::API::Term 0.019 {
 	use Moo::Role;
 	
 	with 'Attean::API::TermOrVariable', 'Attean::API::ResultOrTerm';
@@ -58,8 +58,7 @@ Returns true if the term has a true SPARQL "effective boolean value", false othe
 
 =cut
 
-	sub ebv { return 0; }
-	
+	requires 'ebv';
 	requires 'compare';
 	
 	sub __ntriples_string {
@@ -106,15 +105,15 @@ Returns true if the term has a true SPARQL "effective boolean value", false othe
 	}
 }
 
-package Attean::API::Literal 0.012 {
-	use Moo::Role;
+package Attean::API::Literal 0.019 {
 	use IRI;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Maybe Str ConsumerOf);
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Attean::API::Query;
-	use namespace::clean;
+
+	use Moo::Role;
 	
 	with 'Attean::API::Term';
 	with 'Attean::API::SPARQLSerializable';
@@ -290,10 +289,11 @@ package Attean::API::Literal 0.012 {
 	};
 }
 
-package Attean::API::DateTimeLiteral 0.012 {
-	use Moo::Role;
+package Attean::API::DateTimeLiteral 0.019 {
 	use DateTime::Format::W3CDTF;
-	use namespace::clean;
+
+	use Moo::Role;
+
 	sub datetime {
 		my $self	= shift;
 		my $w3c	= DateTime::Format::W3CDTF->new;
@@ -301,16 +301,16 @@ package Attean::API::DateTimeLiteral 0.012 {
 	}
 }
 
-package Attean::API::CanonicalizingLiteral 0.012 {
+package Attean::API::CanonicalizingLiteral 0.019 {
 	use Moo::Role;
 	requires 'canonicalized_term';
 }
 
-package Attean::API::NumericLiteral 0.012 {
-	use Moo::Role;
+package Attean::API::NumericLiteral 0.019 {
 	use Scalar::Util qw(blessed looks_like_number);
-	use namespace::clean;
-	
+
+	use Moo::Role;
+
 	sub compare {
 		my ($a, $b)	= @_;
 		return 1 unless blessed($b);
@@ -497,13 +497,13 @@ package Attean::API::NumericLiteral 0.012 {
 	with 'Attean::API::Literal', 'Attean::API::CanonicalizingLiteral';
 }
 
-package Attean::API::Blank 0.012 {
-	use Moo::Role;
+package Attean::API::Blank 0.019 {
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Attean::API::Query;
-	use namespace::clean;
+
+	use Moo::Role;
 	
 	sub ebv { return 1; }
 	with 'Attean::API::Term', 'Attean::API::BlankOrIRI';
@@ -523,14 +523,14 @@ package Attean::API::Blank 0.012 {
 	}
 }
 
-package Attean::API::IRI 0.012 {
-	use Moo::Role;
+package Attean::API::IRI 0.019 {
 	use IRI;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Attean::API::Query;
-	use namespace::clean;
+
+	use Moo::Role;
 	
 	sub ebv { return 1; }
 	with 'Attean::API::Term', 'Attean::API::BlankOrIRI';
@@ -585,7 +585,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
@@ -593,7 +593,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams.
+Copyright (c) 2014--2018 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
