@@ -7,7 +7,7 @@ Attean::CodeIterator - Iterator implementation backed by a generator function
 
 =head1 VERSION
 
-This document describes Attean::CodeIterator version 0.012
+This document describes Attean::CodeIterator version 0.019
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,7 @@ that will be returned from the iterator.
 
 =cut
 
-package Attean::CodeIterator 0.012 {
+package Attean::CodeIterator 0.019 {
 	use Moo;
 	use Type::Tiny::Role;
 	use Scalar::Util qw(blessed);
@@ -84,7 +84,7 @@ Returns the iterator's next item, or undef upon reaching the end of iteration.
 		}
 		my $role	= $self->item_type;
 		if (Role::Tiny->is_role($role)) {
-			die "CodeIterator item is not a $role" unless (blessed($item) and $item->does($role));
+			die "CodeIterator item is not a $role: $item" unless (blessed($item) and $item->does($role));
 		}
 		return $item;
 	}
@@ -103,7 +103,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
@@ -111,7 +111,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams.
+Copyright (c) 2014--2018 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
