@@ -7,7 +7,7 @@ Attean::Literal - RDF Literals
 
 =head1 VERSION
 
-This document describes Attean::Literal version 0.012
+This document describes Attean::Literal version 0.019
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ Returns true if the literal has a language tag, false otherwise.
 
 =cut
 
-package Attean::Literal 0.012 {
+package Attean::Literal 0.019 {
 	use Moo;
 	use Types::Standard qw(Str Maybe InstanceOf);
 	use Attean::API::Term;
@@ -65,7 +65,14 @@ package Attean::Literal 0.012 {
 		is => 'ro',
 		isa => InstanceOf['Attean::IRI'],
 		required => 1,
-		coerce => sub { blessed($_[0]) ? Attean::IRI->new($_[0]->as_string) : Attean::IRI->new($_[0]) },
+		coerce => sub {
+			my $dt	= shift;
+			if (blessed($dt) and $dt->isa('Attean::IRI')) {
+				return $dt;
+			} else {
+				return blessed($dt) ? Attean::IRI->new($dt->as_string) : Attean::IRI->new($dt)
+			}
+		},
 		default => sub { $XSD_STRING }
 	);
 	has 'ntriples_string'	=> (is => 'ro', isa => Str, lazy => 1, builder => '_ntriples_string');
@@ -83,16 +90,11 @@ package Attean::Literal 0.012 {
 		return $class->$orig(@_);
 	};
 	
-	sub BUILD {
-		my $self	= shift;
-		die unless ($self->has_language or length($self->datatype->as_string));
-	}
-	
 	around 'datatype'	=> sub {
 		my $orig	= shift;
 		my $self	= shift;
 		if ($self->has_language) {
-			return Attean::IRI->new(value => 'http://www.w3.org/2001/XMLSchema#string');
+			return Attean::IRI->new(value => 'http://www.w3.org/1999/02/22-rdf-syntax-ns#langString');
 		} else {
 			return $self->$orig(@_);
 		}
@@ -167,7 +169,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
@@ -175,7 +177,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams.
+Copyright (c) 2014--2018 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
