@@ -7,7 +7,7 @@ AtteanX::Parser::NTuples - Shared functionality for N-Triples and N-Quads parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::NTuples version 0.012
+This document describes AtteanX::Parser::NTuples version 0.019
 
 =head1 SYNOPSIS
 
@@ -23,10 +23,11 @@ This document describes AtteanX::Parser::NTuples version 0.012
 
 =cut
 
-package AtteanX::Parser::NTuples 0.012 {
+package AtteanX::Parser::NTuples 0.019 {
 	use utf8;
 	use Moo;
 	use Attean;
+	use Carp qw(carp);
 	use Encode qw(decode);
 	use namespace::clean;
 
@@ -42,12 +43,15 @@ Parses the given C<< $bytes >> and returns a corresponding L<Attean::API::Term>
 =cut
 
 	sub parse_term_from_string {
-# 		TODO: warn "parse_term_from_string is now called parse_term_from_bytes\n";
+		carp "parse_term_from_string is deprecated and will be removed in Attean 0.019 (use parse_term_from_bytes instead)";
 		return shift->parse_term_from_bytes(@_);
 	}
 	
 	sub parse_term_from_bytes {
 		my $self	= shift;
+		unless (ref($self)) {
+			$self	= $self->new();
+		}
 		my $string	= shift;
 		my $n = $self->_eat_node( 0, $string );
 		return $n;
@@ -138,7 +142,7 @@ the data read from the L<IO::Handle> object C<< $fh >>.
 					# clear out the cache roughly every 50 IRIs
 					%cache	= ();
 				}
-				my $iri	= Attean::IRI->new( _unescape($uri, $lineno) );
+				my $iri	= $self->new_iri( value => _unescape($uri, $lineno) );
 				$cache{$uri}	= $iri;
 				return $iri;
 			}
@@ -199,7 +203,8 @@ the data read from the L<IO::Handle> object C<< $fh >>.
 				substr($_[0],0,3)	= '';
 				my ($uri)	= $_[0] =~ m/^([^>]*)>/;
 				substr($_[0], 0, length($uri)+1)	= '';
-				return Attean::Literal->new( value => $value, datatype => $uri);
+				my $dt	= $self->new_iri(value => $uri);
+				return Attean::Literal->new( value => $value, datatype => $dt);
 			} else {
 				return Attean::Literal->new($value);
 			}
@@ -281,7 +286,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams. This
+Copyright (c) 2014--2018 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
