@@ -10,7 +10,7 @@ AtteanX::Parser::Turtle - Turtle RDF Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::Turtle version 0.007
+This document describes AtteanX::Parser::Turtle version 0.019
 
 =head1 SYNOPSIS
 
@@ -22,16 +22,33 @@ This document describes AtteanX::Parser::Turtle version 0.007
 
 This module implements a parser for the Turtle RDF format.
 
+=head1 ATTRIBUTES
+
+=over 4
+
+=item C<< canonical_media_type >>
+
+=item C<< media_types >>
+
+=item C<< file_extensions >>
+
+=item C<< canonicalize >>
+
+A boolean indicating whether term values should be canonicalized during parsing.
+
+=back
+
 =head1 METHODS
 
 =over 4
 
 =cut
 
-package AtteanX::Parser::Turtle 0.007 {
+package AtteanX::Parser::Turtle 0.019 {
 	use Moo;
 	use Types::Standard qw(Bool ArrayRef HashRef Str Maybe InstanceOf);
 	use utf8;
+	use Carp qw(carp);
 	use Encode qw(encode);
 	use Scalar::Util qw(blessed);
 	use AtteanX::Parser::Turtle::Constants;
@@ -40,37 +57,25 @@ package AtteanX::Parser::Turtle 0.007 {
 	use Attean::API::Parser;
 	use namespace::clean;
 
-=item C<< canonical_media_type >>
-
-Returns the canonical media type for Turtle: text/turtle.
-
-=cut
-
 	sub canonical_media_type { return "text/turtle" }
 
-=item C<< media_types >>
-
-Returns a list of media types that may be parsed with the Turtle parser:
-text/turtle.
-
-=cut
-
 	sub media_types {
 		return [qw(application/x-turtle application/turtle text/turtle)];
 	}
 
-=item C<< file_extensions >>
-
-Returns a list of file extensions that may be parsed with the parser.
-
-=cut
-
 	sub file_extensions { return [qw(ttl)] }
 
 	has 'canonicalize'	=> (is => 'rw', isa => Bool, default => 0);
-	has 'map' => (is => 'ro', isa => HashRef[Str], default => sub { +{} });
+	has '_map' => (is => 'ro', isa => HashRef[Str], default => sub { +{} });
+
+=item C<< has_namespaces >>
+
+Returns true if the parser has a namespace map, false otherwise.
+
+=cut
+
 	has 'namespaces' => (is => 'rw', isa => Maybe[InstanceOf['URI::NamespaceMap']], predicate => 'has_namespaces');
-	has	'stack'	=> (
+	has	'_stack'	=> (
 		is => 'ro',
 		isa => ArrayRef,
 		default => sub { [] },
@@ -123,15 +128,30 @@ the data read from the UTF-8 encoded byte string C<< $data >>.
 		$self->_parse($l);
 	}
 
-=item C<< parse_node ( $string, $base ) >>
+=item C<< parse_term_from_string( $bytes ) >>
+
+This method is deprecated, as the name was misleading.
+Calls should be replaced with C<< parse_term_from_bytes >>.
+	
+=item C<< parse_term_from_bytes ( $bytes, $base ) >>
+
+=item C<< parse_node ( $bytes, $base ) >>
 
 Returns the Attean::API::Term object corresponding to the node whose N-Triples
-serialization is found at the beginning of C<< $string >>.
+serialization is found at the beginning of C<< $bytes >>.
 
 =cut
 
 	sub parse_term_from_string {
+		carp "parse_term_from_string is deprecated and will be removed in Attean 0.019 (use parse_term_from_bytes instead)";
+		return shift->parse_term_from_bytes(@_);
+	}
+	
+	sub parse_term_from_bytes {
 		my $self	= shift;
+		unless (ref($self)) {
+			$self	= $self->new();
+		}
 		return $self->parse_node(@_);
 	}
 	
@@ -161,14 +181,14 @@ serialization is found at the beginning of C<< $string >>.
 	sub _unget_token {
 		my $self	= shift;
 		my $t		= shift;
-		push(@{ $self->stack }, $t);
+		push(@{ $self->_stack }, $t);
 # 		push(@{ $self->{ stack } }, $t);
 	}
 
 	sub _next_nonws {
 		my $self	= shift;
-		if (scalar(@{ $self->stack })) {
-			return pop(@{ $self->stack });
+		if (scalar(@{ $self->_stack })) {
+			return pop(@{ $self->_stack });
 		}
 		my $l		= shift;
 		while (1) {
@@ -202,7 +222,7 @@ serialization is found at the beginning of C<< $string >>.
 		my $t		= shift;
 		my $type	= $t->type;
 	# 		when (WS) {}
-		if ($type == PREFIX or $type == SPARQLPREFIX) {
+		if ($type == TURTLEPREFIX or $type == PREFIX) {
 			$t	= $self->_get_token_type($l, PREFIXNAME);
 			use Data::Dumper;
 			unless (defined($t->value)) {
@@ -217,16 +237,16 @@ serialization is found at the beginning of C<< $string >>.
 			if ($self->has_base) {
 				$args{base}	= $self->base;
 			}
-			my $r	= Attean::IRI->new(%args);
+			my $r	= $self->new_iri(%args);
 			my $iri	= $r->as_string;
-			if ($type == PREFIX) {
+			if ($type == TURTLEPREFIX) {
 				$t	= $self->_get_token_type($l, DOT);
 	# 			$t	= $self->_next_nonws($l);
 	# 			if ($t and $t->type != DOT) {
 	# 				$self->_unget_token($t);
 	# 			}
 			}
-			$self->map->{$name}	= $iri;
+			$self->_map->{$name}	= $iri;
 			if ($self->has_namespaces) {
 				my $ns	= $self->namespaces;
 				unless ($ns->namespace_uri($name)) {
@@ -234,15 +254,15 @@ serialization is found at the beginning of C<< $string >>.
 				}
 			}
 		}
-		elsif ($type == BASE or $type == SPARQLBASE) {
+		elsif ($type == TURTLEBASE or $type == BASE) {
 			$t	= $self->_get_token_type($l, IRI);
 			my %args	= (value => $t->value);
 			if ($self->has_base) {
 				$args{base}	= $self->base;
 			}
-			my $r	= Attean::IRI->new(%args);
+			my $r	= $self->new_iri(%args);
 			my $iri	= $r->as_string;
-			if ($type == BASE) {
+			if ($type == TURTLEBASE) {
 				$t	= $self->_get_token_type($l, DOT);
 	# 			$t	= $self->_next_nonws($l);
 	# 			if ($t and $t->type != DOT) {
@@ -278,7 +298,7 @@ serialization is found at the beginning of C<< $string >>.
 		} elsif ($type == LPAREN) {
 			my $t	= $self->_next_nonws($l);
 			if ($t->type == RPAREN) {
-				$subj	= Attean::IRI->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#nil');
+				$subj	= Attean::IRI->new(value => "http://www.w3.org/1999/02/22-rdf-syntax-ns#nil", lazy => 1);
 			} else {
 				$subj	= Attean::Blank->new();
 				my @objects	= $self->_object($l, $t);
@@ -320,9 +340,9 @@ serialization is found at the beginning of C<< $string >>.
 		my $head	= $subj;
 		while (@objects) {
 			my $obj	= shift(@objects);
-			$self->_assert_triple($head, Attean::IRI->new("${RDF}first"), $obj);
-			my $next	= scalar(@objects) ? Attean::Blank->new() : Attean::IRI->new("${RDF}nil");
-			$self->_assert_triple($head, Attean::IRI->new("${RDF}rest"), $next);
+			$self->_assert_triple($head, Attean::IRI->new(value => "${RDF}first", lazy => 1), $obj);
+			my $next	= scalar(@objects) ? Attean::Blank->new() : Attean::IRI->new(value => "${RDF}nil", lazy => 1);
+			$self->_assert_triple($head, Attean::IRI->new(value => "${RDF}rest", lazy => 1), $next);
 			$head		= $next;
 		}
 	}
@@ -422,7 +442,7 @@ serialization is found at the beginning of C<< $string >>.
 				$self->_throw_error("Expecting object but got only opening paren", $tcopy, $l);
 			}
 			if ($t->type == RPAREN) {
-				$obj	= Attean::IRI->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#nil');
+				$obj	= Attean::IRI->new(value => "http://www.w3.org/1999/02/22-rdf-syntax-ns#nil", lazy => 1);
 			} else {
 				$obj	= Attean::Blank->new();
 				my @objects	= $self->_object($l, $t);
@@ -473,7 +493,7 @@ serialization is found at the beginning of C<< $string >>.
 		my $t		= shift;
 		my $type	= shift || $t->type;
 		if ($type eq A) {
-			state $rdftype	= Attean::IRI->new("${RDF}type");
+			state $rdftype	= Attean::IRI->new(value => "${RDF}type", lazy => 1);
 			return $rdftype;
 		}
 		elsif ($type eq IRI) {
@@ -482,7 +502,7 @@ serialization is found at the beginning of C<< $string >>.
 			my $iri;
 			if ($self->has_base) {
 				$args{base}	= $self->base;
-				my $iri	= Attean::IRI->new(%args);
+				my $iri	= $self->new_iri(%args);
 				return $iri;
 			}
 			
@@ -490,7 +510,7 @@ serialization is found at the beginning of C<< $string >>.
 			 if (my $n = $cache{$value}) {
 				return $n;
 			} else {
-				my $iri	= Attean::IRI->new(%args);
+				my $iri	= $self->new_iri(%args);
 				if (rand() < 0.02) {
 					# clear out the cache roughly every 50 IRIs
 					%cache	= ();
@@ -500,26 +520,26 @@ serialization is found at the beginning of C<< $string >>.
 			}
 		}
 		elsif ($type eq INTEGER) {
-			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new("${XSD}integer"));
+			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new(value => "${XSD}integer", lazy => 1));
 		}
 		elsif ($type eq DECIMAL) {
-			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new("${XSD}decimal"));
+			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new(value => "${XSD}decimal", lazy => 1));
 		}
 		elsif ($type eq DOUBLE) {
-			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new("${XSD}double"));
+			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new(value => "${XSD}double", lazy => 1));
 		}
 		elsif ($type eq BOOLEAN) {
-			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new("${XSD}boolean"));
+			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new(value => "${XSD}boolean", lazy => 1));
 		}
 		elsif ($type eq PREFIXNAME) {
 			my ($ns, $local)	= @{ $t->args };
 			$ns		=~ s/:$//;
-			unless (exists $self->map->{$ns}) {
+			unless (exists $self->_map->{$ns}) {
 				$self->_throw_error("Use of undeclared prefix '$ns'", $t);
 			}
-			my $prefix			= $self->map->{$ns};
+			my $prefix			= $self->_map->{$ns};
 			no warnings 'uninitialized';
-			my $iri				= Attean::IRI->new("${prefix}${local}");
+			my $iri				= $self->new_iri("${prefix}${local}");
 			return $iri;
 		}
 		elsif ($type eq BNODE) {
@@ -569,7 +589,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
+Copyright (c) 2014--2018 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
